@@ -121,7 +121,7 @@ class Run(command.Command):
                             help="Takes in a single test to bypasses test "
                             "discover and just execute the test specified. A "
                             "file may be used in place of a test name.")
-        parser.add_argument('--random', '-r', action="store_true",
+        parser.add_argument('--random', action="store_true",
                             default=False,
                             help="Randomize the test order after they are "
                             "partitioned into separate workers")
@@ -381,7 +381,7 @@ def run_command(config='.stestr.conf', repo_type='file',
         else:
             raise RuntimeError("The Python interpreter was not found and "
                                "PYTHON is not set")
-        run_cmd = python_bin + ' -m subunit.run ' + ids
+        run_cmd = python_bin + ' -m stestr.subunit_runner.run ' + ids
 
         def run_tests():
             run_proc = [('subunit', output.ReturnCodeToSubunit(
